@@ -1,15 +1,13 @@
 //
-// "$Id: Fluid_Image.h,v 1.3.2.3 2000/06/05 21:20:41 mike Exp $"
+// "$Id: Fluid_Image.h,v 1.3.2.4.2.4 2003/08/02 21:17:30 easysw Exp $"
 //
-// Pixmap image header file for the Fast Light Tool Kit (FLTK).
+// Image header file for the Fast Light Tool Kit (FLTK).
 //
 // This class stores the image labels for widgets in fluid.  This is
-// not a class in fltk itself, and this will produce different types of
-// code depending on what the image type is.  There are private subclasses
-// in Fluid_Image.C for each type of image format.  Right now only xpm
-// files are supported.
+// not a class in FLTK itself, and will produce different types of
+// code depending on what the image type is.
 //
-// Copyright 1998-2000 by Bill Spitzak and others.
+// Copyright 1998-2003 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -30,31 +28,37 @@
 //
 
 #ifndef FLUID_IMAGE_H
-#define FLUID_IMAGE_H
+#  define FLUID_IMAGE_H
+
+#  include <FL/Fl_Shared_Image.H>
+
 
 class Fluid_Image {
   const char *name_;
   int refcount;
+  Fl_Shared_Image *img;
 protected:
   Fluid_Image(const char *name); // no public constructor
-  virtual ~Fluid_Image(); // no public destructor
+  ~Fluid_Image(); // no public destructor
 public:
   int written;
   static Fluid_Image* find(const char *);
   void decrement(); // reference counting & automatic free
   void increment();
-  virtual void label(Fl_Widget *) = 0; // set the label of this widget
-  virtual void write_static() = 0;
-  virtual void write_code() = 0;
+  void image(Fl_Widget *); // set the image of this widget
+  void deimage(Fl_Widget *); // set the deimage of this widget
+  void write_static();
+  void write_code(int inactive = 0);
   const char *name() const {return name_;}
 };
 
 // pop up file chooser and return a legal image selected by user,
 // or zero for any errors:
 Fluid_Image *ui_find_image(const char *);
+extern const char *ui_find_image_name;
 
 #endif
 
 //
-// End of "$Id: Fluid_Image.h,v 1.3.2.3 2000/06/05 21:20:41 mike Exp $".
+// End of "$Id: Fluid_Image.h,v 1.3.2.4.2.4 2003/08/02 21:17:30 easysw Exp $".
 //
