@@ -1,9 +1,9 @@
 //
-// "$Id: Fl_Box.cxx,v 1.4.2.2 2000/06/05 21:20:47 mike Exp $"
+// "$Id: Fl_Box.cxx,v 1.4.2.3.2.4 2003/01/30 21:41:23 easysw Exp $"
 //
 // Box widget for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2000 by Bill Spitzak and others.
+// Copyright 1998-2003 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -26,13 +26,17 @@
 #include <FL/Fl_Widget.H>
 #include <FL/Fl_Box.H>
 
-// MRS - shouldn't we inline this?
-
 void Fl_Box::draw() {
   draw_box();
   draw_label();
 }
 
+int Fl_Box::handle(int event) {
+  if (event == FL_ENTER || event == FL_LEAVE) return 1;
+  else return 0;
+}
+
+
 //
-// End of "$Id: Fl_Box.cxx,v 1.4.2.2 2000/06/05 21:20:47 mike Exp $".
+// End of "$Id: Fl_Box.cxx,v 1.4.2.3.2.4 2003/01/30 21:41:23 easysw Exp $".
 //
