@@ -1,9 +1,9 @@
 //
-// "$Id: Fl_Color_Chooser.cxx,v 1.7.2.3 2000/06/05 21:20:50 mike Exp $"
+// "$Id: Fl_Color_Chooser.cxx,v 1.7.2.4.2.6 2003/01/30 21:41:36 easysw Exp $"
 //
 // Color chooser for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2000 by Bill Spitzak and others.
+// Copyright 1998-2003 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -40,15 +40,15 @@
 
 // The "hue box" can be a circle or rectilinear.
 // You get a circle by defining this:
-// #define CIRCLE 1
+#define CIRCLE 1
 // And the "hue box" can auto-update when the value changes
 // you get this by defining this:
 #define UPDATE_HUE_BOX 1
 
 void Fl_Color_Chooser::hsv2rgb(
-	double H, double S, double V, double& r, double& g, double& b) {
+	double H, double S, double V, double& R, double& G, double& B) {
   if (S < 5.0e-6) {
-    r = g = b = V;
+    R = G = B = V;
   } else {
     int i = (int)H;  
     double f = H - (float)i;
@@ -56,27 +56,27 @@ void Fl_Color_Chooser::hsv2rgb(
     double p2 = V*(1.0-S*f);
     double p3 = V*(1.0-S*(1.0-f));
     switch (i) {
-    case 0: r = V;   g = p3;  b = p1;  break;
-    case 1: r = p2;  g = V;   b = p1;  break;
-    case 2: r = p1;  g = V;   b = p3;  break;
-    case 3: r = p1;  g = p2;  b = V;   break;
-    case 4: r = p3;  g = p1;  b = V;   break;
-    case 5: r = V;   g = p1;  b = p2;  break;
+    case 0: R = V;   G = p3;  B = p1;  break;
+    case 1: R = p2;  G = V;   B = p1;  break;
+    case 2: R = p1;  G = V;   B = p3;  break;
+    case 3: R = p1;  G = p2;  B = V;   break;
+    case 4: R = p3;  G = p1;  B = V;   break;
+    case 5: R = V;   G = p1;  B = p2;  break;
     }
   }
 }
 
 void Fl_Color_Chooser::rgb2hsv(
-	double r, double g, double b, double& H, double& S, double& V) {
-  double maxv = r > g ? r : g; if (b > maxv) maxv = b;
+	double R, double G, double B, double& H, double& S, double& V) {
+  double maxv = R > G ? R : G; if (B > maxv) maxv = B;
   V = maxv;
   if (maxv>0) {
-    double minv = r < g ? r : g; if (b < minv) minv = b;
+    double minv = R < G ? R : G; if (B < minv) minv = B;
     S = 1.0 - double(minv)/maxv;
     if (maxv > minv) {
-      if (maxv == r) {H = (g-b)/double(maxv-minv); if (H<0) H += 6.0;}
-      else if (maxv == g) H = 2.0+(b-r)/double(maxv-minv);
-      else H = 4.0+(r-g)/double(maxv-minv);
+      if (maxv == R) {H = (G-B)/double(maxv-minv); if (H<0) H += 6.0;}
+      else if (maxv == G) H = 2.0+(B-R)/double(maxv-minv);
+      else H = 4.0+(R-G)/double(maxv-minv);
     }
   }
 }
@@ -117,13 +117,13 @@ void Fl_Color_Chooser::set_valuators() {
   }
 }
 
-int Fl_Color_Chooser::rgb(double r, double g, double b) {
-  if (r == r_ && g == g_ && b == b_) return 0;
-  r_ = r; g_ = g; b_ = b;
+int Fl_Color_Chooser::rgb(double R, double G, double B) {
+  if (R == r_ && G == g_ && B == b_) return 0;
+  r_ = R; g_ = G; b_ = B;
   double ph = hue_;
   double ps = saturation_;
   double pv = value_;
-  rgb2hsv(r,g,b,hue_,saturation_,value_);
+  rgb2hsv(R,G,B,hue_,saturation_,value_);
   set_valuators();
   if (value_ != pv) {
 #ifdef UPDATE_HUE_BOX
@@ -137,15 +137,15 @@ int Fl_Color_Chooser::rgb(double r, double g, double b) {
   return 1;
 }
 
-int Fl_Color_Chooser::hsv(double h, double s, double v) {
-  h = fmod(h,6.0); if (h < 0.0) h += 6.0;
-  if (s < 0.0) s = 0.0; else if (s > 1.0) s = 1.0;
-  if (v < 0.0) v = 0.0; else if (v > 1.0) v = 1.0;
-  if (h == hue_ && s == saturation_ && v == value_) return 0;
+int Fl_Color_Chooser::hsv(double H, double S, double V) {
+  H = fmod(H,6.0); if (H < 0.0) H += 6.0;
+  if (S < 0.0) S = 0.0; else if (S > 1.0) S = 1.0;
+  if (V < 0.0) V = 0.0; else if (V > 1.0) V = 1.0;
+  if (H == hue_ && S == saturation_ && V == value_) return 0;
   double ph = hue_;
   double ps = saturation_;
   double pv = value_;
-  hue_ = h; saturation_ = s; value_ = v;
+  hue_ = H; saturation_ = S; value_ = V;
   if (value_ != pv) {
 #ifdef UPDATE_HUE_BOX
     huebox.damage(FL_DAMAGE_SCROLL);
@@ -155,7 +155,7 @@ int Fl_Color_Chooser::hsv(double h, double s, double v) {
     huebox.damage(FL_DAMAGE_EXPOSE); 
     valuebox.damage(FL_DAMAGE_SCROLL);
   }
-  hsv2rgb(h,s,v,r_,g_,b_);
+  hsv2rgb(H,S,V,r_,g_,b_);
   set_valuators();
   return 1;
 }
@@ -180,6 +180,10 @@ int Flcc_HueBox::handle(int e) {
   Fl_Color_Chooser* c = (Fl_Color_Chooser*)parent();
   switch (e) {
   case FL_PUSH:
+    if (Fl::visible_focus()) {
+      Fl::focus(this);
+      redraw();
+    }
     ih = c->hue();
     is = c->saturation();
   case FL_DRAG: {
@@ -192,6 +196,15 @@ int Flcc_HueBox::handle(int e) {
     if (Fl::event_state(FL_CTRL)) H = ih;
     if (c->hsv(H, S, c->value())) c->do_callback();
     } return 1;
+  case FL_FOCUS :
+  case FL_UNFOCUS :
+    if (Fl::visible_focus()) {
+      redraw();
+      return 1;
+    }
+    else return 1;
+  case FL_KEYBOARD :
+    return handle_key(Fl::event_key());
   default:
     return 0;
   }
@@ -217,14 +230,53 @@ static void generate_image(void* vv, int X, int Y, int W, uchar* buf) {
   }
 }
 
+int Flcc_HueBox::handle_key(int key) {
+  int w1 = w()-Fl::box_dw(box())-6;
+  int h1 = h()-Fl::box_dh(box())-6;
+  Fl_Color_Chooser* c = (Fl_Color_Chooser*)parent();
+
+#ifdef CIRCLE
+  int X = int(.5*(cos(c->hue()*(M_PI/3.0))*c->saturation()+1) * w1);
+  int Y = int(.5*(1-sin(c->hue()*(M_PI/3.0))*c->saturation()) * h1);
+#else
+  int X = int(c->hue()/6.0*w1);
+  int Y = int((1-c->saturation())*h1);
+#endif
+
+  switch (key) {
+    case FL_Up :
+      Y -= 3;
+      break;
+    case FL_Down :
+      Y += 3;
+      break;
+    case FL_Left :
+      X -= 3;
+      break;
+    case FL_Right :
+      X += 3;
+      break;
+    default :
+      return 0;
+  }
+
+  double Xf, Yf, H, S;
+  Xf = (double)X/(double)w1;
+  Yf = (double)Y/(double)h1;
+  tohs(Xf, Yf, H, S);
+  if (c->hsv(H, S, c->value())) c->do_callback();
+
+  return 1;
+}
+
 void Flcc_HueBox::draw() {
   if (damage()&FL_DAMAGE_ALL) draw_box();
   int x1 = x()+Fl::box_dx(box());
-  int y1 = y()+Fl::box_dy(box());
+  int yy1 = y()+Fl::box_dy(box());
   int w1 = w()-Fl::box_dw(box());
   int h1 = h()-Fl::box_dh(box());
-  if (damage() == FL_DAMAGE_EXPOSE) fl_clip(x1+px,y1+py,6,6);
-  fl_draw_image(generate_image, this, x1, y1, w1, h1);
+  if (damage() == FL_DAMAGE_EXPOSE) fl_clip(x1+px,yy1+py,6,6);
+  fl_draw_image(generate_image, this, x1, yy1, w1, h1);
   if (damage() == FL_DAMAGE_EXPOSE) fl_pop_clip();
   Fl_Color_Chooser* c = (Fl_Color_Chooser*)parent();
 #ifdef CIRCLE
@@ -237,7 +289,7 @@ void Flcc_HueBox::draw() {
   if (X < 0) X = 0; else if (X > w1-6) X = w1-6;
   if (Y < 0) Y = 0; else if (Y > h1-6) Y = h1-6;
   //  fl_color(c->value()>.75 ? FL_BLACK : FL_WHITE);
-  draw_box(FL_UP_BOX,x1+X,y1+Y,6,6,FL_GRAY);
+  draw_box(FL_UP_BOX,x1+X,yy1+Y,6,6,Fl::focus() == this ? FL_FOREGROUND_COLOR : FL_GRAY);
   px = X; py = Y;
 }
 
@@ -248,6 +300,10 @@ int Flcc_ValueBox::handle(int e) {
   Fl_Color_Chooser* c = (Fl_Color_Chooser*)parent();
   switch (e) {
   case FL_PUSH:
+    if (Fl::visible_focus()) {
+      Fl::focus(this);
+      redraw();
+    }
     iv = c->value();
   case FL_DRAG: {
     double Yf;
@@ -255,6 +311,15 @@ int Flcc_ValueBox::handle(int e) {
     if (fabs(Yf-iv)<(3*1.0/h())) Yf = iv;
     if (c->hsv(c->hue(),c->saturation(),Yf)) c->do_callback();
     } return 1;
+  case FL_FOCUS :
+  case FL_UNFOCUS :
+    if (Fl::visible_focus()) {
+      redraw();
+      return 1;
+    }
+    else return 1;
+  case FL_KEYBOARD :
+    return handle_key(Fl::event_key());
   default:
     return 0;
   }
@@ -277,35 +342,60 @@ void Flcc_ValueBox::draw() {
   Fl_Color_Chooser* c = (Fl_Color_Chooser*)parent();
   c->hsv2rgb(c->hue(),c->saturation(),1.0,tr,tg,tb);
   int x1 = x()+Fl::box_dx(box());
-  int y1 = y()+Fl::box_dy(box());
+  int yy1 = y()+Fl::box_dy(box());
   int w1 = w()-Fl::box_dw(box());
   int h1 = h()-Fl::box_dh(box());
-  if (damage() == FL_DAMAGE_EXPOSE) fl_clip(x1,y1+py,w1,6);
-  fl_draw_image(generate_vimage, this, x1, y1, w1, h1);
+  if (damage() == FL_DAMAGE_EXPOSE) fl_clip(x1,yy1+py,w1,6);
+  fl_draw_image(generate_vimage, this, x1, yy1, w1, h1);
   if (damage() == FL_DAMAGE_EXPOSE) fl_pop_clip();
   int Y = int((1-c->value()) * (h1-6));
   if (Y < 0) Y = 0; else if (Y > h1-6) Y = h1-6;
-  draw_box(FL_UP_BOX,x1,y1+Y,w1,6,FL_GRAY);
+  draw_box(FL_UP_BOX,x1,yy1+Y,w1,6,Fl::focus() == this ? FL_FOREGROUND_COLOR : FL_GRAY);
   py = Y;
 }
 
+int Flcc_ValueBox::handle_key(int key) {
+  int h1 = h()-Fl::box_dh(box())-6;
+  Fl_Color_Chooser* c = (Fl_Color_Chooser*)parent();
+
+  int Y = int((1-c->value()) * h1);
+  if (Y < 0) Y = 0; else if (Y > h1) Y = h1;
+
+  switch (key) {
+    case FL_Up :
+      Y -= 3;
+      break;
+    case FL_Down :
+      Y += 3;
+      break;
+    default :
+      return 0;
+  }
+
+  double Yf;
+  Yf = 1-((double)Y/(double)h1);
+  if (c->hsv(c->hue(),c->saturation(),Yf)) c->do_callback();
+
+  return 1;
+}
+
 ////////////////////////////////////////////////////////////////
 
 void Fl_Color_Chooser::rgb_cb(Fl_Widget* o, void*) {
   Fl_Color_Chooser* c = (Fl_Color_Chooser*)(o->parent());
-  double r = c->rvalue.value();
-  double g = c->gvalue.value();
-  double b = c->bvalue.value();
+  double R = c->rvalue.value();
+  double G = c->gvalue.value();
+  double B = c->bvalue.value();
   if (c->mode() == M_HSV) {
-    if (c->hsv(r,g,b)) c->do_callback();
+    if (c->hsv(R,G,B)) c->do_callback();
     return;
   }
   if (c->mode() != M_RGB) {
-    r = r/255;
-    g = g/255;
-    b = b/255;
+    R = R/255;
+    G = G/255;
+    B = B/255;
   }
-  if (c->rgb(r,g,b)) c->do_callback();
+  if (c->rgb(R,G,B)) c->do_callback();
 }
 
 void Fl_Color_Chooser::mode_cb(Fl_Widget* o, void*) {
@@ -320,14 +410,14 @@ void Fl_Color_Chooser::mode_cb(Fl_Widget* o, void*) {
 ////////////////////////////////////////////////////////////////
 
 Fl_Color_Chooser::Fl_Color_Chooser(int X, int Y, int W, int H, const char* L)
-  : Fl_Group(0,0,180,100,L),
-    huebox(0,0,100,100),
-    valuebox(100,0,20,100),
-    choice(120,0,60,20),
-    rvalue(120,20,60,23),
-    gvalue(120,43,60,23),
-    bvalue(120,66,60,23),
-    resize_box(0,89,100,9)
+  : Fl_Group(0,0,195,115,L),
+    huebox(0,0,115,115),
+    valuebox(115,0,20,115),
+    choice(140,0,55,25),
+    rvalue(140,30,55,25),
+    gvalue(140,60,55,25),
+    bvalue(140,90,55,25),
+    resize_box(0,0,115,115)
 {
   end();
   resizable(resize_box);
@@ -384,15 +474,15 @@ extern const char* fl_ok;
 extern const char* fl_cancel;
 
 int fl_color_chooser(const char* name, double& r, double& g, double& b) {
-  Fl_Window window(210,153,name);
-  Fl_Color_Chooser chooser(5, 5, 200, 95);
-  ColorChip ok_color(5, 105, 95, 23);
-  Fl_Return_Button ok_button(5, 128, 95, 23, fl_ok);
-  ColorChip cancel_color(110, 105, 95, 23);
+  Fl_Window window(215,200,name);
+  Fl_Color_Chooser chooser(10, 10, 195, 115);
+  ColorChip ok_color(10, 130, 95, 25);
+  Fl_Return_Button ok_button(10, 165, 95, 25, fl_ok);
+  ColorChip cancel_color(110, 130, 95, 25);
   cancel_color.r = uchar(255*r+.5); ok_color.r = cancel_color.r;
   ok_color.g = cancel_color.g = uchar(255*g+.5);
   ok_color.b = cancel_color.b = uchar(255*b+.5);
-  Fl_Button cancel_button(110, 128, 95, 23, fl_cancel);
+  Fl_Button cancel_button(110, 165, 95, 25, fl_cancel);
   window.resizable(chooser);
   chooser.rgb(r,g,b);
   chooser.callback(chooser_cb, &ok_color);
@@ -431,5 +521,5 @@ int fl_color_chooser(const char* name, uchar& r, uchar& g, uchar& b) {
 }
 
 //
-// End of "$Id: Fl_Color_Chooser.cxx,v 1.7.2.3 2000/06/05 21:20:50 mike Exp $".
+// End of "$Id: Fl_Color_Chooser.cxx,v 1.7.2.4.2.6 2003/01/30 21:41:36 easysw Exp $".
 //
