@@ -1,9 +1,9 @@
 //
-// "$Id: Fl_Group.cxx,v 1.8.2.7 2000/10/21 20:01:56 spitzak Exp $"
+// "$Id: Fl_Group.cxx,v 1.8.2.8.2.21 2003/01/30 21:41:51 easysw Exp $"
 //
 // Group widget for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2000 by Bill Spitzak and others.
+// Copyright 1998-2003 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -23,11 +23,12 @@
 // Please report all bugs and problems to "fltk-bugs@fltk.org".
 //
 
-// The Fl_Group is the only defined container type in fltk.
+// The Fl_Group is the only defined container type in FLTK.
 
 // Fl_Window itself is a subclass of this, and most of the event
 // handling is designed so windows themselves work correctly.
 
+#include <stdio.h>
 #include <FL/Fl.H>
 #include <FL/Fl_Group.H>
 #include <FL/Fl_Window.H>
@@ -48,6 +49,13 @@ int Fl_Group::find(const Fl_Widget* o) const {
   return i;
 }
 
+// Metrowerks CodeWarrior and others can't export the static
+// class member: current_, so these methods can't be inlined...
+void Fl_Group::begin() {current_ = this;}
+void Fl_Group::end() {current_ = (Fl_Group*)parent();}
+Fl_Group *Fl_Group::current() {return current_;}
+void Fl_Group::current(Fl_Group *g) {current_ = g;}
+
 extern Fl_Widget* fl_oldfocus; // set by Fl::focus
 
 // For back-compatability, we must adjust all events sent to child
@@ -55,11 +63,28 @@ extern Fl_Widget* fl_oldfocus; // set by Fl::focus
 
 static int send(Fl_Widget* o, int event) {
   if (o->type() < FL_WINDOW) return o->handle(event);
+  switch ( event )
+  {
+  case FL_DND_ENTER:
+  case FL_DND_DRAG:
+    // figure out correct type of event:
+    event = (o->contains(Fl::belowmouse())) ? FL_DND_DRAG : FL_DND_ENTER;
+  }
   int save_x = Fl::e_x; Fl::e_x -= o->x();
   int save_y = Fl::e_y; Fl::e_y -= o->y();
   int ret = o->handle(event);
   Fl::e_y = save_y;
   Fl::e_x = save_x;
+  switch ( event )
+  {
+  case FL_ENTER:
+  case FL_DND_ENTER:
+    // Successful completion of FL_ENTER means the widget is now the
+    // belowmouse widget, but only call Fl::belowmouse if the child
+    // widget did not do so:
+    if (!o->contains(Fl::belowmouse())) Fl::belowmouse(o);
+    break;
+  }
   return ret;
 }
 
@@ -140,17 +165,33 @@ int Fl_Group::handle(int event) {
   case FL_MOVE:
     for (i = children(); i--;) {
       o = a[i];
-      if (o->takesevents() && Fl::event_inside(o)) {
+      if (o->visible() && Fl::event_inside(o)) {
 	if (o->contains(Fl::belowmouse())) {
 	  return send(o,FL_MOVE);
-	} else if (send(o,FL_ENTER)) {
+	} else {
+	  if (!o->contains(Fl::belowmouse())) Fl::belowmouse(o);
+	  if (send(o,FL_ENTER)) return 1;
+	}
+      }
+    }
+    Fl::belowmouse(this);
+    return 1;
+
+  case FL_DND_ENTER:
+  case FL_DND_DRAG:
+    for (i = children(); i--;) {
+      o = a[i];
+      if (o->takesevents() && Fl::event_inside(o)) {
+	if (o->contains(Fl::belowmouse())) {
+	  return send(o,FL_DND_DRAG);
+	} else if (send(o,FL_DND_ENTER)) {
 	  if (!o->contains(Fl::belowmouse())) Fl::belowmouse(o);
 	  return 1;
 	}
       }
     }
     Fl::belowmouse(this);
-    return 1;
+    return 0;
 
   case FL_PUSH:
     for (i = children(); i--;) {
@@ -164,6 +205,21 @@ int Fl_Group::handle(int event) {
     }
     return 0;
 
+  case FL_RELEASE:
+  case FL_DRAG:
+    o = Fl::pushed();
+    if (o == this) return 0;
+    else if (o) send(o,event);
+    else {
+      for (i = children(); i--;) {
+	o = a[i];
+	if (o->takesevents() && Fl::event_inside(o)) {
+	  if (send(o,event)) return 1;
+	}
+      }
+    }
+    return 0;
+
   case FL_DEACTIVATE:
   case FL_ACTIVATE:
     for (i = children(); i--;) {
@@ -181,8 +237,24 @@ int Fl_Group::handle(int event) {
     return 1;
 
   default:
-    return 0;
+    // For all other events, try to give to each child, starting at focus:
+    for (i = 0; i < children(); i ++)
+      if (Fl::focus_ == a[i]) break;
 
+    if (i >= children()) i = 0;
+
+    if (children()) {
+      for (int j = i;;) {
+        if (a[j]->takesevents() || event != FL_MOUSEWHEEL) {
+          if (send(a[j], event)) return 1;
+	}
+        j++;
+        if (j >= children()) j = 0;
+        if (j == i) break;
+      }
+    }
+
+    return 0;
   }
 }
 
@@ -261,7 +333,7 @@ void Fl_Group::clear() {
   int old_children = children();
   // clear everything now, in case fl_fix_focus recursively calls us:
   children_ = 0;
-  // array_ = 0; dont do this, it will clobber old_array if only one child
+  //array_ = 0; //dont do this, it will clobber old_array if only one child
   savedfocus_ = 0;
   resizable_ = this;
   init_sizes();
@@ -269,13 +341,14 @@ void Fl_Group::clear() {
   Fl_Widget*const* a = old_array;
   for (int i=old_children; i--;) {
     Fl_Widget* o = *a++;
-    // test the parent to see if child already destructed:
     if (o->parent() == this) delete o;
   }
   if (old_children > 1) free((void*)old_array);
 }
 
-Fl_Group::~Fl_Group() {clear();}
+Fl_Group::~Fl_Group() {
+  clear();
+}
 
 void Fl_Group::insert(Fl_Widget &o, int index) {
   if (o.parent()) {
@@ -309,6 +382,7 @@ void Fl_Group::insert(Fl_Widget &o, int index) {
 void Fl_Group::add(Fl_Widget &o) {insert(o, children_);}
 
 void Fl_Group::remove(Fl_Widget &o) {
+  if (!children_) return;
   int i = find(o);
   if (i >= children_) return;
   if (&o == savedfocus_) savedfocus_ = 0;
@@ -376,7 +450,7 @@ short* Fl_Group::sizes() {
 
 void Fl_Group::resize(int X, int Y, int W, int H) {
 
-  if (!resizable() || W==w() && H==h()) {
+  if (!resizable() || W==w() && H==h() ) {
 
     if (type() < FL_WINDOW) {
       int dx = X-x();
@@ -410,46 +484,44 @@ void Fl_Group::resize(int X, int Y, int W, int H) {
     for (int i=children_; i--;) {
       Fl_Widget* o = *a++;
 #if 1
-      int X = *p++;
-      if (X >= IR) X += dw;
-      else if (X > IX) X = IX+((X-IX)*(IR+dw-IX)+(IR-IX)/2)/(IR-IX);
+      int XX = *p++;
+      if (XX >= IR) XX += dw;
+      else if (XX > IX) XX = IX+((XX-IX)*(IR+dw-IX)+(IR-IX)/2)/(IR-IX);
       int R = *p++;
       if (R >= IR) R += dw;
       else if (R > IX) R = IX+((R-IX)*(IR+dw-IX)+(IR-IX)/2)/(IR-IX);
 
-      int Y = *p++;
-      if (Y >= IB) Y += dh;
-      else if (Y > IY) Y = IY+((Y-IY)*(IB+dh-IY)+(IB-IY)/2)/(IB-IY);
+      int YY = *p++;
+      if (YY >= IB) YY += dh;
+      else if (YY > IY) YY = IY+((YY-IY)*(IB+dh-IY)+(IB-IY)/2)/(IB-IY);
       int B = *p++;
       if (B >= IB) B += dh;
       else if (B > IY) B = IY+((B-IY)*(IB+dh-IY)+(IB-IY)/2)/(IB-IY);
 #else // much simpler code from Francois Ostiguy:
-      int X = *p++;
-      if (X >= IR) X += dw;
-      else if (X > IX) X = X + dw * (X-IX)/(IR-IX);
+      int XX = *p++;
+      if (XX >= IR) XX += dw;
+      else if (XX > IX) XX += dw * (XX-IX)/(IR-IX);
       int R = *p++;
       if (R >= IR) R += dw;
       else if (R > IX) R = R + dw * (R-IX)/(IR-IX);
 
-      int Y = *p++;
-      if (Y >= IB) Y += dh;
-      else if (Y > IY) Y = Y + dh*(Y-IY)/(IB-IY);
+      int YY = *p++;
+      if (YY >= IB) YY += dh;
+      else if (YY > IY) YY = YY + dh*(YY-IY)/(IB-IY);
       int B = *p++;
       if (B >= IB) B += dh;
       else if (B > IY) B = B + dh*(B-IY)/(IB-IY);
 #endif
-      o->resize(X+dx, Y+dy, R-X, B-Y);
+      o->resize(XX+dx, YY+dy, R-XX, B-YY);
     }
   }
 
   Fl_Widget::resize(X,Y,W,H);
 }
 
-void Fl_Group::draw() {
+void Fl_Group::draw_children() {
   Fl_Widget*const* a = array();
   if (damage() & ~FL_DAMAGE_CHILD) { // redraw the entire thing:
-    draw_box();
-    draw_label();
     for (int i=children_; i--;) {
       Fl_Widget& o = **a++;
       draw_child(o);
@@ -460,58 +532,66 @@ void Fl_Group::draw() {
   }
 }
 
+void Fl_Group::draw() {
+  if (damage() & ~FL_DAMAGE_CHILD) { // redraw the entire thing:
+    draw_box();
+    draw_label();
+  }
+  draw_children();
+}
+
 // Draw a child only if it needs it:
-void Fl_Group::update_child(Fl_Widget& w) const {
-  if (w.damage() && w.visible() && w.type() < FL_WINDOW &&
-      fl_not_clipped(w.x(), w.y(), w.w(), w.h())) {
-    w.draw();	
-    w.clear_damage();
+void Fl_Group::update_child(Fl_Widget& widget) const {
+  if (widget.damage() && widget.visible() && widget.type() < FL_WINDOW &&
+      fl_not_clipped(widget.x(), widget.y(), widget.w(), widget.h())) {
+    widget.draw();	
+    widget.clear_damage();
   }
 }
 
 // Force a child to redraw:
-void Fl_Group::draw_child(Fl_Widget& w) const {
-  if (w.visible() && w.type() < FL_WINDOW &&
-      fl_not_clipped(w.x(), w.y(), w.w(), w.h())) {
-    w.clear_damage(FL_DAMAGE_ALL);
-    w.draw();
-    w.clear_damage();
+void Fl_Group::draw_child(Fl_Widget& widget) const {
+  if (widget.visible() && widget.type() < FL_WINDOW &&
+      fl_not_clipped(widget.x(), widget.y(), widget.w(), widget.h())) {
+    widget.clear_damage(FL_DAMAGE_ALL);
+    widget.draw();
+    widget.clear_damage();
   }
 }
 
 extern char fl_draw_shortcut;
 
 // Parents normally call this to draw outside labels:
-void Fl_Group::draw_outside_label(const Fl_Widget& w) const {
-  if (!w.visible()) return;
+void Fl_Group::draw_outside_label(const Fl_Widget& widget) const {
+  if (!widget.visible()) return;
   // skip any labels that are inside the widget:
-  if (!(w.align()&15) || (w.align() & FL_ALIGN_INSIDE)) return;
+  if (!(widget.align()&15) || (widget.align() & FL_ALIGN_INSIDE)) return;
   // invent a box that is outside the widget:
-  int align = w.align();
-  int X = w.x();
-  int Y = w.y();
-  int W = w.w();
-  int H = w.h();
-  if (align & FL_ALIGN_TOP) {
-    align ^= (FL_ALIGN_BOTTOM|FL_ALIGN_TOP);
+  int a = widget.align();
+  int X = widget.x();
+  int Y = widget.y();
+  int W = widget.w();
+  int H = widget.h();
+  if (a & FL_ALIGN_TOP) {
+    a ^= (FL_ALIGN_BOTTOM|FL_ALIGN_TOP);
     Y = y();
-    H = w.y()-Y;
-  } else if (align & FL_ALIGN_BOTTOM) {
-    align ^= (FL_ALIGN_BOTTOM|FL_ALIGN_TOP);
+    H = widget.y()-Y;
+  } else if (a & FL_ALIGN_BOTTOM) {
+    a ^= (FL_ALIGN_BOTTOM|FL_ALIGN_TOP);
     Y = Y+H;
     H = y()+h()-Y;
-  } else if (align & FL_ALIGN_LEFT) {
-    align ^= (FL_ALIGN_LEFT|FL_ALIGN_RIGHT);
+  } else if (a & FL_ALIGN_LEFT) {
+    a ^= (FL_ALIGN_LEFT|FL_ALIGN_RIGHT);
     X = x();
-    W = w.x()-X-3;
-  } else if (align & FL_ALIGN_RIGHT) {
-    align ^= (FL_ALIGN_LEFT|FL_ALIGN_RIGHT);
+    W = widget.x()-X-3;
+  } else if (a & FL_ALIGN_RIGHT) {
+    a ^= (FL_ALIGN_LEFT|FL_ALIGN_RIGHT);
     X = X+W+3;
     W = x()+this->w()-X;
   }
-  w.draw_label(X,Y,W,H,(Fl_Align)align);
+  widget.draw_label(X,Y,W,H,(Fl_Align)a);
 }
 
 //
-// End of "$Id: Fl_Group.cxx,v 1.8.2.7 2000/10/21 20:01:56 spitzak Exp $".
+// End of "$Id: Fl_Group.cxx,v 1.8.2.8.2.21 2003/01/30 21:41:51 easysw Exp $".
 //
