@@ -1,9 +1,9 @@
 //
-// "$Id: Fl_Menu_Button.cxx,v 1.4.2.2 2000/06/05 21:20:54 mike Exp $"
+// "$Id: Fl_Menu_Button.cxx,v 1.4.2.3.2.7 2003/01/30 21:42:20 easysw Exp $"
 //
 // Menu button widget for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2000 by Bill Spitzak and others.
+// Copyright 1998-2003 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -31,12 +31,15 @@ void Fl_Menu_Button::draw() {
   if (!box() || type()) return;
   draw_box(box(), color());
   draw_label();
+  if (Fl::focus() == this) draw_focus();
   if (box() == FL_FLAT_BOX) return; // for XForms compatability
   int H = (labelsize()-3)&-2;
   int X = x()+w()-H*2;
   int Y = y()+(h()-H)/2;
-  fl_color(FL_DARK3); fl_line(X+H/2, Y+H, X, Y, X+H, Y);
-  fl_color(FL_LIGHT3); fl_line(X+H, Y, X+H/2, Y+H);
+  fl_color(active_r() ? FL_DARK3 : fl_inactive(FL_DARK3));
+  fl_line(X+H/2, Y+H, X, Y, X+H, Y);
+  fl_color(active_r() ? FL_LIGHT3 : fl_inactive(FL_LIGHT3));
+  fl_line(X+H, Y, X+H/2, Y+H);
 }
 
 const Fl_Menu_Item* Fl_Menu_Button::popup() {
@@ -62,11 +65,25 @@ int Fl_Menu_Button::handle(int e) {
     } else if (type()) {
       if (!(type() & (1 << (Fl::event_button()-1)))) return 0;
     }
+    if (Fl::visible_focus()) Fl::focus(this);
     popup();
     return 1;
+  case FL_KEYBOARD:
+    if (!box()) return 0;
+    if (Fl::event_key() == ' ' &&
+        !(Fl::event_state() & (FL_SHIFT | FL_CTRL | FL_ALT | FL_META))) {
+      popup();
+      return 1;
+    } else return 0;
   case FL_SHORTCUT:
     if (Fl_Widget::test_shortcut()) {popup(); return 1;}
     return test_shortcut() != 0;
+  case FL_FOCUS:
+  case FL_UNFOCUS:
+    if (box() && Fl::visible_focus()) {
+      redraw();
+      return 1;
+    }
   default:
     return 0;
   }
@@ -78,5 +95,5 @@ Fl_Menu_Button::Fl_Menu_Button(int X,int Y,int W,int H,const char *l)
 }
 
 //
-// End of "$Id: Fl_Menu_Button.cxx,v 1.4.2.2 2000/06/05 21:20:54 mike Exp $".
+// End of "$Id: Fl_Menu_Button.cxx,v 1.4.2.3.2.7 2003/01/30 21:42:20 easysw Exp $".
 //
