@@ -1,9 +1,9 @@
 //
-// "$Id: Fl_Window_hotspot.cxx,v 1.7.2.2 2000/06/05 21:20:59 mike Exp $"
+// "$Id: Fl_Window_hotspot.cxx,v 1.7.2.3.2.5 2003/01/30 21:42:59 easysw Exp $"
 //
 // Common hotspot routines for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2000 by Bill Spitzak and others.
+// Copyright 1998-2003 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -25,19 +25,20 @@
 
 #include <FL/Fl.H>
 #include <FL/Fl_Window.H>
+#include <FL/x.H>
 
-#ifdef WIN32
-#include <FL/win32.H>
-#endif
+void Fl_Window::hotspot(int X, int Y, int offscreen) {
+  int mx,my;
 
-void Fl_Window::hotspot(int X, int Y, int /*offscreen*/) {
-  int mx,my; Fl::get_mouse(mx,my);
+  // Update the screen position based on the mouse position.
+  Fl::get_mouse(mx,my);
   X = mx-X; Y = my-Y;
-#if 0
-  // Both the WIN32 and X versions do this to all windows all the time...
+
+  // If offscreen is 0 (the default), make sure that the window
+  // stays on the screen, if possible.
   if (!offscreen) {
-#ifdef WIN32
-    //These will be used by reference, so we must passed different variables
+#if defined(WIN32) || defined(__APPLE__)
+    // These will be used by reference, so we must passed different variables
     int bt,bx,by;
     x(X);y(Y);
     Fl_X::fake_X_wm(this, X, Y, bt, bx, by);
@@ -45,37 +46,39 @@ void Fl_Window::hotspot(int X, int Y, int /*offscreen*/) {
     if (X==x()) x(X-1);
 #else
     if (border()) {
-      // ensure border is on screen:
+      // Ensure border is on screen; these values are generic enough
+      // to work with many window managers, and are based on KDE defaults.
       const int top = 20;
-      const int left = 1;
-      const int right = 1;
-      const int bottom = 1;
-      if (X+w()+right > Fl::w()) X = Fl::w()-right-w();
-      if (X-left < 0) X = left;
-      if (Y+h()+bottom > Fl::h()) Y = Fl::h()-bottom-h();
-      if (Y-top < 0) Y = top;
+      const int left = 4;
+      const int right = 4;
+      const int bottom = 8;
+      if (X+w()+right > Fl::w()-Fl::x()) X = Fl::w()-Fl::x()-right-w();
+      if (X-left < Fl::x()) X = left;
+      if (Y+h()+bottom > Fl::h()-Fl::y()) Y = Fl::h()-Fl::y()-bottom-h();
+      if (Y-top < Fl::y()) Y = top;
     }
     // now insure contents are on-screen (more important than border):
-    if (X+w() > Fl::w()) X = Fl::w()-w();
-    if (X < 0) X = 0;
-    if (Y+h() > Fl::h()) Y = Fl::h()-h();
-    if (Y < 0) Y = 0;
+    if (X+w() > Fl::w()-Fl::x()) X = Fl::w()-Fl::x()-w();
+    if (X < Fl::x()) X = Fl::x();
+    if (Y+h() > Fl::h()-Fl::y()) Y = Fl::h()-Fl::y()-h();
+    if (Y < Fl::y()) Y = Fl::y();
 #endif
   }
-#endif
+
   position(X,Y);
 }
 
 void Fl_Window::hotspot(const Fl_Widget *o, int offscreen) {
   int X = o->w()/2;
   int Y = o->h()/2;
-  while (o != this) {
+  while (o != this && o) {
     X += o->x(); Y += o->y();
     o = o->window();
   }
   hotspot(X,Y,offscreen);
 }
 
+
 //
-// End of "$Id: Fl_Window_hotspot.cxx,v 1.7.2.2 2000/06/05 21:20:59 mike Exp $".
+// End of "$Id: Fl_Window_hotspot.cxx,v 1.7.2.3.2.5 2003/01/30 21:42:59 easysw Exp $".
 //
