@@ -1,5 +1,5 @@
 //
-// "$Id: Fl_arg.cxx,v 1.5.2.8.2.14 2003/01/30 21:43:03 easysw Exp $"
+// "$Id: Fl_arg.cxx,v 1.5.2.8.2.16 2003/08/02 13:49:17 easysw Exp $"
 //
 // Optional argument initialization code for the Fast Light Tool Kit (FLTK).
 //
@@ -174,39 +174,35 @@ int Fl::args(int argc, char** argv, int& i, int (*cb)(int,char**,int&)) {
   return i;
 }
 
-
 // show a main window, use any parsed arguments
 void Fl_Window::show(int argc, char **argv) {
-  if (!argc) {show(); return;}
-  if (!arg_called) {
+  if (argc && !arg_called) Fl::args(argc,argv);
+
+  Fl::get_system_colors();
+
 #if !defined(WIN32) && !defined(__APPLE__)
-    // Get defaults for drag-n-drop and focus...
-    const char *key = 0, *val;
+  // Get defaults for drag-n-drop and focus...
+  const char *key = 0, *val;
 
-    fl_open_display();
+  if (Fl::first_window()) key = Fl::first_window()->xclass();
+  if (!key) key = "fltk";
 
-    if (Fl::first_window()) key = Fl::first_window()->xclass();
-    if (!key) key = "fltk";
+  val = XGetDefault(fl_display, key, "dndTextOps");
+  if (val) Fl::dnd_text_ops(strcasecmp(val, "true") == 0 ||
+                            strcasecmp(val, "on") == 0 ||
+                            strcasecmp(val, "yes") == 0);
 
-    val = XGetDefault(fl_display, key, "dndTextOps");
-    if (val) Fl::dnd_text_ops(strcasecmp(val, "true") == 0 ||
+  val = XGetDefault(fl_display, key, "tooltips");
+  if (val) Fl_Tooltip::enable(strcasecmp(val, "true") == 0 ||
                               strcasecmp(val, "on") == 0 ||
                               strcasecmp(val, "yes") == 0);
 
-    val = XGetDefault(fl_display, key, "tooltips");
-    if (val) Fl_Tooltip::enable(strcasecmp(val, "true") == 0 ||
-                                strcasecmp(val, "on") == 0 ||
-                                strcasecmp(val, "yes") == 0);
-
-    val = XGetDefault(fl_display, key, "visibleFocus");
-    if (val) Fl::visible_focus(strcasecmp(val, "true") == 0 ||
-                               strcasecmp(val, "on") == 0 ||
-                               strcasecmp(val, "yes") == 0);
+  val = XGetDefault(fl_display, key, "visibleFocus");
+  if (val) Fl::visible_focus(strcasecmp(val, "true") == 0 ||
+                             strcasecmp(val, "on") == 0 ||
+                             strcasecmp(val, "yes") == 0);
 #endif // !WIN32 && !__APPLE__
 
-    Fl::args(argc,argv);
-  }
-
   // set colors first, so background_pixel is correct:
   static char beenhere;
   if (!beenhere) {
@@ -420,5 +416,5 @@ int XParseGeometry(const char* string, int* x, int* y,
 #endif // ifdef WIN32
 
 //
-// End of "$Id: Fl_arg.cxx,v 1.5.2.8.2.14 2003/01/30 21:43:03 easysw Exp $".
+// End of "$Id: Fl_arg.cxx,v 1.5.2.8.2.16 2003/08/02 13:49:17 easysw Exp $".
 //
