@@ -1,5 +1,5 @@
 //
-// "$Id: Fl_win32.cxx,v 1.33.2.37.2.44 2003/01/30 21:43:11 easysw Exp $"
+// "$Id: Fl_win32.cxx,v 1.33.2.37.2.47 2003/06/15 04:27:35 easysw Exp $"
 //
 // WIN32-specific code for the Fast Light Tool Kit (FLTK).
 //
@@ -397,6 +397,8 @@ void Fl::paste(Fl_Widget &receiver, int clipboard) {
     // called in response to FL_PASTE!
     Fl::e_text = fl_selection_buffer[clipboard];
     Fl::e_length = fl_selection_length[clipboard];
+
+    if (!Fl::e_text) Fl::e_text = (char *)"";
     receiver.handle(FL_PASTE);
   } else {
     if (!OpenClipboard(NULL)) return;
@@ -613,7 +615,8 @@ static LRESULT CALLBACK WndProc(HWND hWnd, UINT uMsg, WPARAM wParam, LPARAM lPar
     fl_save_pen();
     i->flush();
     fl_restore_pen();
-    ValidateRgn(hWnd,i->region);
+    if (window->type() == FL_DOUBLE_WINDOW) ValidateRgn(hWnd,0);
+    else ValidateRgn(hWnd,i->region);
     window->clear_damage();
     } return 0;
 
@@ -1192,5 +1195,5 @@ void Fl_Window::make_current() {
 }
 
 //
-// End of "$Id: Fl_win32.cxx,v 1.33.2.37.2.44 2003/01/30 21:43:11 easysw Exp $".
+// End of "$Id: Fl_win32.cxx,v 1.33.2.37.2.47 2003/06/15 04:27:35 easysw Exp $".
 //
