@@ -1,7 +1,7 @@
 /*
- * "$Id: fl_call_main.c,v 1.1.2.7 2000/06/05 21:21:06 mike Exp $"
+ * "$Id: fl_call_main.c,v 1.1.2.11.2.4 2003/01/30 21:43:28 easysw Exp $"
  *
- * Copyright 1998-2000 by Bill Spitzak and others.
+ * Copyright 1998-2003 by Bill Spitzak and others.
  *
  * fl_call_main() calls main() for you Windows people.  Needs to be done in C
  * because Borland C++ won't let you call main() from C++.
@@ -48,17 +48,23 @@
 
 #include <windows.h>
 #include <stdio.h>
+#include <stdlib.h>
+
+#ifdef __MWERKS__
+# include <crtl.h>
+#endif
 
 extern int main(int, char *[]);
+
 #ifdef BORLAND5
-#define __argc _argc
-#define __argv _argv
+# define __argc _argc
+# define __argv _argv
 #endif
-extern int  __argc;
-extern char **__argv;
 
 int WINAPI WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance,
                              LPSTR lpCmdLine, int nCmdShow) {
+  int rc;
+
 #ifdef _DEBUG
  /*
   * If we are using compiling in debug mode, open a console window so
@@ -77,12 +83,23 @@ int WINAPI WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance,
 #endif /* _DEBUG */
 
   /* Run the standard main entry point function... */
-  return main(__argc, __argv);
+  rc = main(__argc, __argv);
+
+#ifdef _DEBUG
+  fclose(stdin);
+  fclose(stdout);
+  fclose(stderr);
+#endif /* _DEBUG */
+
+  return rc;
 }
 
+#else
+/* This code to prevent "empty translation unit" or similar warnings... */
+static void dummy(void) {dummy();}
 #endif
 
 /*
- * End of "$Id: fl_call_main.c,v 1.1.2.7 2000/06/05 21:21:06 mike Exp $".
+ * End of "$Id: fl_call_main.c,v 1.1.2.11.2.4 2003/01/30 21:43:28 easysw Exp $".
  */
 
