@@ -1,9 +1,9 @@
 //
-// "$Id: fl_color_win32.cxx,v 1.14.2.2 2000/06/05 21:21:06 mike Exp $"
+// "$Id: fl_color_win32.cxx,v 1.14.2.3.2.7 2003/01/30 21:43:30 easysw Exp $"
 //
 // WIN32 color functions for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2000 by Bill Spitzak and others.
+// Copyright 1998-2003 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -34,7 +34,7 @@
 
 #include <config.h>
 #include <FL/Fl.H>
-#include <FL/win32.H>
+#include <FL/x.H>
 #include <FL/fl_draw.H>
 
 static unsigned fl_cmap[256] = {
@@ -47,8 +47,19 @@ Fl_XMap fl_xmap[256];
 Fl_XMap* fl_current_xmap;
 
 HPALETTE fl_palette;
-HPEN tmppen=0;
-HBRUSH tmpbrush=0;
+static HPEN tmppen=0;
+static HBRUSH tmpbrush=0;
+static HPEN savepen=0;
+
+void fl_save_pen(void) {
+    if(!tmppen) tmppen = CreatePen(PS_SOLID, 1, 0);
+    savepen = (HPEN)SelectObject(fl_gc, tmppen);
+}
+
+void fl_restore_pen(void) {
+    if (savepen) SelectObject(fl_gc, savepen);
+    savepen = 0;
+}
 
 static void clear_xmap(Fl_XMap& xmap) {
   if (xmap.pen) {
@@ -73,27 +84,33 @@ static void set_xmap(Fl_XMap& xmap, COLORREF c) {
 Fl_Color fl_color_;
 
 void fl_color(Fl_Color i) {
-  fl_color_ = i;
-  Fl_XMap &xmap = fl_xmap[i];
-  if (!xmap.pen) {
+  if (i & 0xffffff00) {
+    unsigned rgb = (unsigned)i;
+    fl_color((uchar)(rgb >> 24), (uchar)(rgb >> 16), (uchar)(rgb >> 8));
+  } else {
+    fl_color_ = i;
+    Fl_XMap &xmap = fl_xmap[i];
+    if (!xmap.pen) {
 #if USE_COLORMAP
-    if (fl_palette) {
-      set_xmap(xmap, PALETTEINDEX(i));
-    } else {
+      if (fl_palette) {
+	set_xmap(xmap, PALETTEINDEX(i));
+      } else {
 #endif
-      unsigned c = fl_cmap[i];
-      set_xmap(xmap, RGB(uchar(c>>24), uchar(c>>16), uchar(c>>8)));
+	unsigned c = fl_cmap[i];
+	set_xmap(xmap, RGB(uchar(c>>24), uchar(c>>16), uchar(c>>8)));
 #if USE_COLORMAP
+      }
+#endif
     }
-#endif
+    fl_current_xmap = &xmap;
+    SelectObject(fl_gc, (HGDIOBJ)(xmap.pen));
   }
-  fl_current_xmap = &xmap;
-  SelectObject(fl_gc, (HGDIOBJ)(xmap.pen));
 }
 
 void fl_color(uchar r, uchar g, uchar b) {
   static Fl_XMap xmap;
   COLORREF c = RGB(r,g,b);
+  fl_color_ = fl_rgb_color(r, g, b);
   if (!xmap.pen || c != xmap.rgb) {
     clear_xmap(xmap);
     set_xmap(xmap, c);
@@ -206,5 +223,5 @@ fl_select_palette(void)
 #endif
 
 //
-// End of "$Id: fl_color_win32.cxx,v 1.14.2.2 2000/06/05 21:21:06 mike Exp $".
+// End of "$Id: fl_color_win32.cxx,v 1.14.2.3.2.7 2003/01/30 21:43:30 easysw Exp $".
 //
