@@ -1,9 +1,9 @@
 //
-// "$Id: fl_engraved_label.cxx,v 1.4.2.2 2000/06/05 21:21:07 mike Exp $"
+// "$Id: fl_engraved_label.cxx,v 1.4.2.3.2.3 2003/01/30 21:43:45 easysw Exp $"
 //
 // Engraved label drawing routines for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2000 by Bill Spitzak and others.
+// Copyright 1998-2003 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -73,19 +73,19 @@ static void fl_embossed_label(
   innards(o, X, Y, W, H, align, data, 7);
 }
 
-Fl_Labeltype define_FL_SHADOW_LABEL() {
+Fl_Labeltype fl_define_FL_SHADOW_LABEL() {
   Fl::set_labeltype(_FL_SHADOW_LABEL, fl_shadow_label, 0);
   return _FL_SHADOW_LABEL;
 }
-Fl_Labeltype define_FL_ENGRAVED_LABEL() {
+Fl_Labeltype fl_define_FL_ENGRAVED_LABEL() {
   Fl::set_labeltype(_FL_ENGRAVED_LABEL, fl_engraved_label, 0);
   return _FL_ENGRAVED_LABEL;
 }
-Fl_Labeltype define_FL_EMBOSSED_LABEL() {
+Fl_Labeltype fl_define_FL_EMBOSSED_LABEL() {
   Fl::set_labeltype(_FL_EMBOSSED_LABEL, fl_embossed_label, 0);
   return _FL_EMBOSSED_LABEL;
 }
 
 //
-// End of "$Id: fl_engraved_label.cxx,v 1.4.2.2 2000/06/05 21:21:07 mike Exp $".
+// End of "$Id: fl_engraved_label.cxx,v 1.4.2.3.2.3 2003/01/30 21:43:45 easysw Exp $".
 //
