@@ -1,9 +1,9 @@
 //
-// "$Id: fl_oval_box.cxx,v 1.4.2.2 2000/06/05 21:21:08 mike Exp $"
+// "$Id: fl_oval_box.cxx,v 1.4.2.3.2.3 2003/01/30 21:43:59 easysw Exp $"
 //
 // Oval box drawing code for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2000 by Bill Spitzak and others.
+// Copyright 1998-2003 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -51,7 +51,7 @@ static void fl_oval_shadow_box(int x, int y, int w, int h, Fl_Color c) {
 }
 
 extern void fl_internal_boxtype(Fl_Boxtype, Fl_Box_Draw_F*);
-Fl_Boxtype define_FL_OVAL_BOX() {
+Fl_Boxtype fl_define_FL_OVAL_BOX() {
   fl_internal_boxtype(_FL_OSHADOW_BOX,fl_oval_shadow_box);
   fl_internal_boxtype(_FL_OVAL_FRAME,fl_oval_frame);
   fl_internal_boxtype(_FL_OFLAT_BOX,fl_oval_flat_box);
@@ -60,5 +60,5 @@ Fl_Boxtype define_FL_OVAL_BOX() {
 }
 
 //
-// End of "$Id: fl_oval_box.cxx,v 1.4.2.2 2000/06/05 21:21:08 mike Exp $".
+// End of "$Id: fl_oval_box.cxx,v 1.4.2.3.2.3 2003/01/30 21:43:59 easysw Exp $".
 //
