@@ -1,9 +1,9 @@
 //
-// "$Id: fl_round_box.cxx,v 1.6.2.2 2000/06/05 21:21:09 mike Exp $"
+// "$Id: fl_round_box.cxx,v 1.6.2.3.2.4 2003/01/30 21:44:08 easysw Exp $"
 //
 // Round box drawing routines for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2000 by Bill Spitzak and others.
+// Copyright 1998-2003 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -80,7 +80,7 @@ static void draw(int which, int x,int y,int w,int h, int inset, uchar color)
 
 extern uchar* fl_gray_ramp();
 
-static void fl_round_down_box(int x, int y, int w, int h, Fl_Color bgcolor) {
+void fl_round_down_box(int x, int y, int w, int h, Fl_Color bgcolor) {
   uchar *g = fl_gray_ramp();
   draw(FILL,	    x,   y, w,   h, 2, bgcolor);
   draw(UPPER_LEFT,  x+1, y, w-2, h, 0, g['N']);
@@ -94,7 +94,7 @@ static void fl_round_down_box(int x, int y, int w, int h, Fl_Color bgcolor) {
   draw(CLOSED,	    x,   y, w,   h, 2, g['A']);
 }
 
-static void fl_round_up_box(int x, int y, int w, int h, Fl_Color bgcolor) {
+void fl_round_up_box(int x, int y, int w, int h, Fl_Color bgcolor) {
   uchar *g = fl_gray_ramp();
   draw(FILL,	    x,   y, w,   h, 2, bgcolor);
   draw(LOWER_RIGHT, x+1, y, w-2, h, 0, g['H']);
@@ -109,12 +109,12 @@ static void fl_round_up_box(int x, int y, int w, int h, Fl_Color bgcolor) {
 }
 
 extern void fl_internal_boxtype(Fl_Boxtype, Fl_Box_Draw_F*);
-Fl_Boxtype define_FL_ROUND_UP_BOX() {
+Fl_Boxtype fl_define_FL_ROUND_UP_BOX() {
   fl_internal_boxtype(_FL_ROUND_DOWN_BOX, fl_round_down_box);
   fl_internal_boxtype(_FL_ROUND_UP_BOX, fl_round_up_box);
   return _FL_ROUND_UP_BOX;
 }
 
 //
-// End of "$Id: fl_round_box.cxx,v 1.6.2.2 2000/06/05 21:21:09 mike Exp $".
+// End of "$Id: fl_round_box.cxx,v 1.6.2.3.2.4 2003/01/30 21:44:08 easysw Exp $".
 //
