@@ -1,9 +1,9 @@
 //
-// "$Id: fl_vertex.cxx,v 1.5.2.2 2000/06/05 21:21:11 mike Exp $"
+// "$Id: fl_vertex.cxx,v 1.5.2.3.2.7 2003/01/30 21:44:26 easysw Exp $"
 //
 // Portable drawing routines for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2000 by Bill Spitzak and others.
+// Copyright 1998-2003 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -24,7 +24,7 @@
 //
 
 // Portable drawing code for drawing arbitrary shapes with
-// simple 2D transformations.  See also fl_arc.C
+// simple 2D transformations.  See also fl_arc.cxx
 
 #include <FL/fl_draw.H>
 #include <FL/x.H>
@@ -113,7 +113,7 @@ static void fl_transformed_vertex(COORD_T x, COORD_T y) {
 }
 
 void fl_transformed_vertex(double xf, double yf) {
-  fl_transformed_vertex(COORD_T(xf+.5), COORD_T(yf+.5));
+  fl_transformed_vertex(COORD_T(rint(xf)), COORD_T(rint(yf)));
 }
 
 void fl_vertex(double x,double y) {
@@ -123,14 +123,24 @@ void fl_vertex(double x,double y) {
 void fl_end_points() {
 #ifdef WIN32
   for (int i=0; i<n; i++) SetPixel(fl_gc, p[i].x, p[i].y, fl_RGB());
+#elif defined(__APPLE__)
+  for (int i=0; i<n; i++) { MoveTo(p[i].x, p[i].y); Line(0, 0); } 
 #else
   if (n>1) XDrawPoints(fl_display, fl_window, fl_gc, p, n, 0);
 #endif
 }
 
 void fl_end_line() {
+  if (n < 2) {
+    fl_end_points();
+    return;
+  }
 #ifdef WIN32
   if (n>1) Polyline(fl_gc, p, n);
+#elif defined(__APPLE__)
+  if (n<=1) return;
+  MoveTo(p[0].x, p[0].y);
+  for (int i=1; i<n; i++) LineTo(p[i].x, p[i].y);
 #else
   if (n>1) XDrawLines(fl_display, fl_window, fl_gc, p, n, 0);
 #endif
@@ -148,11 +158,23 @@ void fl_end_loop() {
 
 void fl_end_polygon() {
   fixloop();
+  if (n < 3) {
+    fl_end_line();
+    return;
+  }
 #ifdef WIN32
   if (n>2) {
     SelectObject(fl_gc, fl_brush());
     Polygon(fl_gc, p, n);
   }
+#elif defined(__APPLE__)
+  if (n<=1) return;
+  PolyHandle ph = OpenPoly();
+  MoveTo(p[0].x, p[0].y);
+  for (int i=1; i<n; i++) LineTo(p[i].x, p[i].y);
+  ClosePoly();
+  PaintPoly(ph);
+  KillPoly(ph);
 #else
   if (n>2) XFillPolygon(fl_display, fl_window, fl_gc, p, n, Convex, 0);
 #endif
@@ -187,11 +209,23 @@ void fl_gap() {
 
 void fl_end_complex_polygon() {
   fl_gap();
+  if (n < 3) {
+    fl_end_line();
+    return;
+  }
 #ifdef WIN32
   if (n>2) {
     SelectObject(fl_gc, fl_brush());
     PolyPolygon(fl_gc, p, counts, numcount);
   }
+#elif defined(__APPLE__)
+  if (n<=1) return;
+  PolyHandle ph = OpenPoly();
+  MoveTo(p[0].x, p[0].y);
+  for (int i=1; i<n; i++) LineTo(p[i].x, p[i].y);
+  ClosePoly();
+  PaintPoly(ph);
+  KillPoly(ph);
 #else
   if (n>2) XFillPolygon(fl_display, fl_window, fl_gc, p, n, 0, 0);
 #endif
@@ -206,16 +240,19 @@ void fl_circle(double x, double y,double r) {
   double yt = fl_transform_y(x,y);
   double rx = r * (m.c ? sqrt(m.a*m.a+m.c*m.c) : fabs(m.a));
   double ry = r * (m.b ? sqrt(m.b*m.b+m.d*m.d) : fabs(m.d));
-  int llx = int(xt-rx+.5);
-  int w = int(xt+rx+.5)-llx;
-  int lly = int(yt-ry+.5);
-  int h = int(yt+ry+.5)-lly;
+  int llx = (int)rint(xt-rx);
+  int w = (int)rint(xt+rx)-llx;
+  int lly = (int)rint(yt-ry);
+  int h = (int)rint(yt+ry)-lly;
 #ifdef WIN32
   if (what==POLYGON) {
     SelectObject(fl_gc, fl_brush());
     Pie(fl_gc, llx, lly, llx+w, lly+h, 0,0, 0,0); 
   } else
     Arc(fl_gc, llx, lly, llx+w, lly+h, 0,0, 0,0); 
+#elif defined(__APPLE__)
+  Rect rt; rt.left=llx; rt.right=llx+w; rt.top=lly; rt.bottom=lly+h;
+  (what == POLYGON ? PaintOval : FrameOval)(&rt);
 #else
   (what == POLYGON ? XFillArc : XDrawArc)
     (fl_display, fl_window, fl_gc, llx, lly, w, h, 0, 360*64);
@@ -223,5 +260,5 @@ void fl_circle(double x, double y,double r) {
 }
 
 //
-// End of "$Id: fl_vertex.cxx,v 1.5.2.2 2000/06/05 21:21:11 mike Exp $".
+// End of "$Id: fl_vertex.cxx,v 1.5.2.3.2.7 2003/01/30 21:44:26 easysw Exp $".
 //
