@@ -1,5 +1,5 @@
 /*
- * "$Id: vsnprintf.c,v 1.3.2.3 2000/06/05 21:21:13 mike Exp $"
+ * "$Id: vsnprintf.c,v 1.3.2.5.2.3 2003/01/30 21:44:40 easysw Exp $"
  *
  * vsnprintf() function for the Fast Light Tool Kit (FLTK).
  *
@@ -17,7 +17,7 @@
  * Only handles formats that are both documented in the glibc man page
  * for printf and also handled by your system's sprintf().
  *
- * Copyright 1998-2000 by Bill Spitzak and others.
+ * Copyright 1998-2003 by Bill Spitzak and others.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -38,16 +38,19 @@
  */
 
 #include <stdio.h>
-#include <stdarg.h>
-#include <config.h>
+#include "flstring.h"
 
-#if !HAVE_VSNPRINTF
+#ifdef HAVE_SYS_STDTYPES_H
+#  include <sys/stdtypes.h>
+#endif /* HAVE_SYS_STDTYPES_H */
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-int vsnprintf(char* str, size_t size, const char* fmt, va_list ap) {
+#if !HAVE_VSNPRINTF
+
+int fl_vsnprintf(char* str, size_t size, const char* fmt, va_list ap) {
   const char* e = str+size-1;
   char* p = str;
   char copy[20];
@@ -115,7 +118,7 @@ int vsnprintf(char* str, size_t size, const char* fmt, va_list ap) {
 
 #if !HAVE_SNPRINTF
 
-int snprintf(char* str, size_t size, const char* fmt, ...) {
+int fl_snprintf(char* str, size_t size, const char* fmt, ...) {
   int ret;
   va_list ap;
   va_start(ap, fmt);
@@ -124,13 +127,13 @@ int snprintf(char* str, size_t size, const char* fmt, ...) {
   return ret;
 }
 
+#endif
+
 #ifdef __cplusplus
 }
 #endif
 
-#endif
-
 /*
- * End of "$Id: vsnprintf.c,v 1.3.2.3 2000/06/05 21:21:13 mike Exp $".
+ * End of "$Id: vsnprintf.c,v 1.3.2.5.2.3 2003/01/30 21:44:40 easysw Exp $".
  */
 
