@@ -1,9 +1,9 @@
 //
-// "$Id: browser.cxx,v 1.5.2.5 2000/12/08 15:44:24 easysw Exp $"
+// "$Id: browser.cxx,v 1.5.2.6.2.5 2003/01/30 21:44:59 easysw Exp $"
 //
 // Browser test program for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2000 by Bill Spitzak and others.
+// Copyright 1998-2003 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -63,7 +63,8 @@ That was a blank line above this.
 #include <FL/Fl_Select_Browser.H>
 #include <FL/Fl_Double_Window.H>
 #include <FL/Fl_Button.H>
-#include <FL/Fl_Input.H>
+#include <FL/Fl_Int_Input.H>
+#include <FL/fl_ask.H>
 #include <stdio.h>
 #include <string.h>
 #include <errno.h>
@@ -74,7 +75,7 @@ Fl_Button	*top,
 		*bottom,
 		*middle,
 		*visible;
-Fl_Input	*field;
+Fl_Int_Input	*field;
 
 void b_cb(Fl_Widget* o, void*) {
   printf("callback, selection = %d, event_clicks = %d\n",
@@ -84,6 +85,12 @@ void b_cb(Fl_Widget* o, void*) {
 void show_cb(Fl_Widget *o, void *) {
   int line = atoi(field->value());
 
+  if (!line) {
+    fl_alert("Please enter a number in the text field\n"
+             "before clicking on the buttons.");
+    return;
+  }
+
   if (o == top)
     browser->topline(line);
   else if (o == bottom)
@@ -107,12 +114,29 @@ int main(int argc, char **argv) {
   // browser->scrollbar_right();
   //browser->has_scrollbar(Fl_Browser::BOTH_ALWAYS);
   if (!browser->load(fname)) {
+#ifdef _MSC_VER
+    // if 'browser' was started from the VisualC environment in Win32, 
+    // the current directory is set to the environment itself, 
+    // so we need to correct the browser file path
+    int done = 1;
+    if ( i == argc ) 
+    {
+      fname = "../test/browser.cxx";
+      done = browser->load(fname);
+    }
+    if ( !done )
+    {
+      printf("Can't load %s, %s\n", fname, strerror(errno));
+      exit(1);
+    }
+#else
     printf("Can't load %s, %s\n", fname, strerror(errno));
     exit(1);
+#endif
   }
   browser->position(0);
 
-  field = new Fl_Input(50, 350, 350, 25, "Line #:");
+  field = new Fl_Int_Input(50, 350, 350, 25, "Line #:");
   field->callback(show_cb);
 
   top = new Fl_Button(0, 375, 100, 25, "Top");
@@ -133,6 +157,6 @@ int main(int argc, char **argv) {
 }
 
 //
-// End of "$Id: browser.cxx,v 1.5.2.5 2000/12/08 15:44:24 easysw Exp $".
+// End of "$Id: browser.cxx,v 1.5.2.6.2.5 2003/01/30 21:44:59 easysw Exp $".
 //
 
