@@ -1,9 +1,9 @@
 //
-// "$Id: demo.cxx,v 1.8.2.4 2000/08/20 04:35:17 spitzak Exp $"
+// "$Id: demo.cxx,v 1.8.2.5.2.8 2003/01/30 21:45:22 easysw Exp $"
 //
 // Main demo program for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2000 by Bill Spitzak and others.
+// Copyright 1998-2003 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -173,6 +173,8 @@ void push_menu(const char* nnn)
     bn = numb2but(i,n-1);
     but[bn]->show();
     but[bn]->label(menus[men].iname[i]);
+    if (menus[men].icommand[i][0] != '@') but[bn]->tooltip(menus[men].icommand[i]);
+    else but[bn]->tooltip(0);
   }
   strcpy(stack[stsize],nnn);
   stsize++;
@@ -311,10 +313,16 @@ int load_the_menu(const char* fname)
 }
 
 int main(int argc, char **argv) {
+  putenv("FLTK_DOCDIR=../documentation");
   create_the_forms();
   char buf[256];
   strcpy(buf, argv[0]);
-  filename_setext(buf,".menu");
+#if ( defined _MSC_VER || defined __MWERKS__ ) && defined _DEBUG
+  // MS_VisualC appends a 'd' to debugging executables. remove it.
+  fl_filename_setext( buf, "" );
+  buf[ strlen(buf)-1 ] = 0;
+#endif
+  fl_filename_setext(buf,".menu");
   const char *fname = buf;
   int i = 0;
   if (!Fl::args(argc,argv,i) || i < argc-1)
@@ -323,7 +331,7 @@ int main(int argc, char **argv) {
 
   if (!load_the_menu(fname)) Fl::fatal("Can't open %s",fname);
   strcpy(buf,fname);
-  const char *c = filename_name(buf);
+  const char *c = fl_filename_name(buf);
   if (c > buf) {buf[c-buf] = 0; chdir(buf);}
   push_menu("@main");
   form->show(argc,argv);
@@ -332,6 +340,6 @@ int main(int argc, char **argv) {
 }
 
 //
-// End of "$Id: demo.cxx,v 1.8.2.4 2000/08/20 04:35:17 spitzak Exp $".
+// End of "$Id: demo.cxx,v 1.8.2.5.2.8 2003/01/30 21:45:22 easysw Exp $".
 //
 
