@@ -1,5 +1,5 @@
 //
-// "$Id: forms.cxx,v 1.4.2.2 2000/06/05 21:21:19 mike Exp $"
+// "$Id: forms.cxx,v 1.4.2.4.2.4 2003/01/30 21:45:32 easysw Exp $"
 //
 // Another forms demo for the Fast Light Tool Kit (FLTK).
 //
@@ -9,7 +9,7 @@
 // This demo show the different boxtypes. Note that some
 // boxtypes are not appropriate for some objects
 //
-// Copyright 1998-2000 by Bill Spitzak and others.
+// Copyright 1998-2003 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -34,7 +34,7 @@
 static int border = 1; // changed from FL_TRANSIENT for fltk
 // (this is so the close box and Esc work to close the window)
 
-typedef struct { int val; char *name; } VN_struct;
+typedef struct { int val; const char *name; } VN_struct;
 #define VN(a) {a,#a}
 
 // static VN_struct gmode[] =
@@ -61,6 +61,8 @@ static VN_struct btypes[]=
    {FL_ROUNDED3D_DOWNBOX,"rounded3d downbox"},
    {FL_OVAL3D_UPBOX,"oval3d upbox"},
    {FL_OVAL3D_DOWNBOX,"oval3d downbox"},
+   {FL_PLASTIC_UP_BOX,"plastic upbox"},
+   {FL_PLASTIC_DOWN_BOX,"plastic downbox"},
    /* sentinel */
    {-1}
 };
@@ -165,7 +167,7 @@ create_the_forms (void)
 
 /*************** Main Routine ***********************/
 
-char *browserlines[] = {
+const char *browserlines[] = {
    " ", "@C1@c@l@bObjects Demo",   " ",
    "This demo shows you all",      "objects that currently",
    "exist in the Forms Library.",  " ",
@@ -184,7 +186,7 @@ int
 main (int argc, char *argv[])
 {
   FL_COLOR c = FL_BLACK;
-  char **p;
+  const char **p;
   VN_struct *vn;
 
   fl_initialize(&argc, argv, "FormDemo", 0, 0);
@@ -229,5 +231,5 @@ main (int argc, char *argv[])
 }
 
 //
-// End of "$Id: forms.cxx,v 1.4.2.2 2000/06/05 21:21:19 mike Exp $".
+// End of "$Id: forms.cxx,v 1.4.2.4.2.4 2003/01/30 21:45:32 easysw Exp $".
 //
