@@ -1,9 +1,9 @@
 //
-// "$Id: message.cxx,v 1.5.2.2 2000/06/05 21:21:22 mike Exp $"
+// "$Id: message.cxx,v 1.5.2.3.2.5 2003/01/30 21:45:55 easysw Exp $"
 //
 // Message test program for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2000 by Bill Spitzak and others.
+// Copyright 1998-2003 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -29,11 +29,12 @@
 #include <stdio.h>
 
 int main(int, char **) {
+  Fl::scheme(NULL);
 
-  fl_message("Spelling check sucessfull, %d errors found with %g%% confidence",
+  fl_message("Spelling check sucessful, %d errors found with %g%% confidence",
 	     1002, 100*(15/77.0));
 
-  fl_alert("Quantum fluctuations in the space-time continuim detected, "
+  fl_alert("Quantum fluctuations in the space-time continuum detected, "
 	   "you have %g seconds to comply.", 10.0);
 
   printf("fl_ask returned %d\n",
@@ -54,5 +55,5 @@ int main(int, char **) {
 }
 
 //
-// End of "$Id: message.cxx,v 1.5.2.2 2000/06/05 21:21:22 mike Exp $".
+// End of "$Id: message.cxx,v 1.5.2.3.2.5 2003/01/30 21:45:55 easysw Exp $".
 //
