@@ -1,5 +1,5 @@
 //
-// "$Id: subwindow.cxx,v 1.5.2.4 2000/06/05 21:21:24 mike Exp $"
+// "$Id: subwindow.cxx,v 1.5.2.5.2.3 2003/01/30 21:46:03 easysw Exp $"
 //
 // Nested window test program for the Fast Light Tool Kit (FLTK).
 //
@@ -8,7 +8,7 @@
 // Buttons and pop-up menu should work, indicating that mouse positions
 // are being correctly translated.
 //
-// Copyright 1998-2000 by Bill Spitzak and others.
+// Copyright 1998-2003 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -151,7 +151,7 @@ const char* bigmess =
 #endif
 ;
 
-int main(int, char **) {
+int main(int argc, char **argv) {
   testwindow *window =
     new testwindow(FL_UP_BOX,400,400,"outer");
   new Fl_Toggle_Button(310,310,80,80,"&outer");
@@ -178,10 +178,10 @@ int main(int, char **) {
   popup->type(Fl_Menu_Button::POPUP3);
   popup->add("This|is|a popup|menu");
   popup->add(bigmess);
-  window->show();
+  window->show(argc, argv);
   return Fl::run();
 }
 
 //
-// End of "$Id: subwindow.cxx,v 1.5.2.4 2000/06/05 21:21:24 mike Exp $".
+// End of "$Id: subwindow.cxx,v 1.5.2.5.2.3 2003/01/30 21:46:03 easysw Exp $".
 //
